@@ -32,9 +32,11 @@ import debmake.debian
 import debmake.debs
 import debmake.debug
 import debmake.dist
+import debmake.kludge
 import debmake.origtar
 import debmake.para
 import debmake.sanity
+import debmake.scanfiles
 import debmake.tar
 import debmake.untar
 #######################################################################
@@ -42,7 +44,7 @@ import debmake.untar
 #######################################################################
 
 __programname__     = 'debmake'
-__version__         = '4.0.7'
+__version__         = '4.1.4'
 __copyright__       = 'Copyright © 2014 Osamu Aoki <osamu@debian.org>'
 __license__         = '''\
 Permission is hereby granted, free of charge, to any person obtaining a
@@ -65,7 +67,10 @@ SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 '''
 
 __debian_policy__   = '3.9.5'   # debian policy version
-__debian_compat__   = '9'       # dpkg compatibility level in debian/comapt
+__debian_compat__   = '9'       # debhelper compatibility level in 
+                                # debian/comapt
+                                # Adjust this to 8 or less if 
+                                # backporting to pre-wheezy
 
 #######################################################################
 # main program
@@ -91,6 +96,8 @@ def main():
     para['build_depends']   = {'debhelper (>=' + para['compat'] +')'}
     para['desc'] = ''
     para['desc_long'] = ''
+    para['export'] = set()
+    para['override'] = set()
     # get prefix for install --user/ ,, --prefix/ ,, --home
     fullparent = os.path.dirname(sys.argv[0])
     if fullparent == '.':
@@ -98,7 +105,7 @@ def main():
     else:
         para['base_path'] = os.path.dirname(fullparent)
     para = debmake.para.para(para)
-    debmake.debug.debug_para('D: post para', para)
+    debmake.debug.debug_para('Dp: @post-para para[*]', para)
 #######################################################################
 # -v: print version and copyright notice and exit
 #######################################################################
@@ -112,40 +119,48 @@ def main():
 #######################################################################
 # -c: scan source for copyright+ license text, print and exit
 #######################################################################
-    if para['copyright']:
-        print('I: scan source for copyright+license text', file=sys.stderr)
-        print(debmake.copyright.copyright('package',set()))
+    if para['copyright'] !=0:
+        print('I: scan source for copyright+license text and file extensions', file=sys.stderr)
+        (nonlink_files, xml_html_files, binary_files, huge_files, counter, count_list) = debmake.scanfiles.scanfiles()
+        data = debmake.copyright.check_copyright(nonlink_files, mode=para['copyright'])
+        print(debmake.copyright.copyright('package', set(), data, xml_html_files, binary_files, huge_files, mode=para['copyright']))
+        return
+#######################################################################
+# -k: compare debian/copyright with the source and exit
+#######################################################################
+    if para['kludge'] !=0:
+        print('I: compare debian/copyright with the source', file=sys.stderr)
+        debmake.kludge.kludge(para['kludge'])
         return
 #######################################################################
 # sanity check parameters without digging deep into source tree
 #######################################################################
     print('I: sanity check of parameters', file=sys.stderr)
     para = debmake.sanity.sanity(para)
-    debmake.debug.debug_para('D: post-sanity', para)
+    debmake.debug.debug_para('Dp: @post-sanity para[*]', para)
     print('I: pkg="{}", ver="{}", rev="{}"'.format(para['package'], para['version'], para['revision']), file=sys.stderr)
 #######################################################################
 # -d: make dist (with upstream buildsystem dist/sdist target)
 #######################################################################
     if para['dist']:
         print('I: make the upstream tarball with "make dist" equivalents', file=sys.stderr)
-        para['version'] = debmake.dist.dist(para['package'], para['version'], para['targz'], para['parent'])
-        para['srcdir'] = para['package'] + '-' + para['version']
-        para['tarball'] = para['package'] + '-' + para['version'] + '.' + para['targz']
-        debmake.debug.debug_para('D: post-dist', para)
+        para = debmake.dist.dist(para)
+        debmake.debug.debug_para('Dp: @post-dist para[*]', para)
+        print('I: pkg="{}", ver="{}", rev="{}"'.format(para['package'], para['version'], para['revision']), file=sys.stderr)
 #######################################################################
 # -t: make tar (with "tar --exclude=debian" command)
 #######################################################################
     elif para['tar']:
         print('I: make the upstream tarball with "tar --exclude=debian"', file=sys.stderr)
         debmake.tar.tar(para['tarball'], para['targz'], para['srcdir'], para['parent'], para['yes'])
-        debmake.debug.debug_para('D: post-tar', para)
+        debmake.debug.debug_para('Dp: @post-tar para[*]', para)
 #######################################################################
 # -a, -d: extract archive from tarball (tar -xvzf)
 #######################################################################
     if para['archive'] or para['dist']:
         print('I: untar the upstream tarball', file=sys.stderr)
         debmake.untar.untar(para['tarball'], para['targz'], para['srcdir'], para['dist'], para['tar'], para['parent'], para['yes'])
-        debmake.debug.debug_para('D: post-untar', para)
+        debmake.debug.debug_para('Dp: @post-untar para[*]', para)
 #######################################################################
 # always: generate orig tarball if missing and non-native package
 #######################################################################
@@ -155,7 +170,10 @@ def main():
         print('W: parent dirtectory should be "{}".  (If you use pbuilder, this may be OK.)'.format(para['srcdir']), file=sys.stderr)
     if not para['native']:
         print('I: provide {}_{}.orig.tar.gz for non-native Debian package'.format(para['package'], para['version']), file=sys.stderr)
+        # ln -sf parent/dist/Foo-1.0.tar.gz foo_1.0.orig.tar.gz
         debmake.origtar.origtar(para['package'], para['version'], para['targz'], para['tarball'], para['parent'])
+        para['tarball'] = para['package'] + '_' + para['version'] + '.orig.' + para['targz']
+        debmake.debug.debug_para('Dp: @post-origtar para[*]', para)
 #######################################################################
 # -q: quit here before generating template debian/* package files
 #######################################################################
@@ -167,10 +185,12 @@ def main():
 #######################################################################
     print('I: parse binary package settings: {}'.format(para['binaryspec']), file=sys.stderr)
     para['debs'] = debmake.debs.debs(para['binaryspec'], para['package'], para['monoarch'], para['dh_with'])
+    debmake.debug.debug_debs("Dd: para['debs'] =>", para['debs'])
     print('I: analyze the source tree', file=sys.stderr)
     para = debmake.analyze.analyze(para)
+    debmake.debug.debug_para('Dp: @post-analyze para[*]', para)
     #debmake.gui()          # GUI setting
-    #debmake.debug.debug_para('D: post-gui', para)
+    #debmake.debug.debug_para('Dp: @post-gui para[*]', para)
 #######################################################################
 # Make debian/* package files
 #######################################################################
@@ -180,20 +200,35 @@ def main():
 # Make Debian package(s)
 #######################################################################
     if para['judge']:
-        command = 'fakeroot dpkg-depcheck -b -f -catch-alternatives debian/rules install >../{}.build-dep.log'.format(para['package'])
-        print('I: {}'.format(command), file=sys.stderr)
+        command = 'fakeroot dpkg-depcheck -m -C -o ../{0}.depcheck.log -f -catch-alternatives debian/rules install >../{0}.build.log 2>&1'.format(para['package'])
+        print('I: $ {}'.format(command), file=sys.stderr)
         if subprocess.call(command, shell=True) != 0:
-            print('E: failed to run dpkg-buildcheck.', file=sys.stderr)
+            print('E: failed to run dpkg-depcheck.', file=sys.stderr)
             exit(1)
-        if len(para['debs']) > 1:
-            command = 'find debian/tmp -type f | sed -e "s/^debian\/tmp\///" >../{}.install.log'.format(para['package'])
-            print('I: {}'.format(command), file=sys.stderr)
+        command = 'LANG=C ; sed -e "1d" < ../{0}.depcheck.log | sort >../{0}.build-dep.log'.format(para['package'])
+        print('I: $ {}'.format(command), file=sys.stderr)
+        if subprocess.call(command, shell=True) != 0:
+            print('E: failed to run sort on build-dep.', file=sys.stderr)
+            exit(1)
+        if len(para['debs']) == 1:
+            bpackage = para['debs'][0]['package']
+            command = 'LANG=C; find debian/' + bpackage + ' -type f 2>&1 | sed -e "s/^debian\/' + bpackage + '\///" | sort >../{0}.install.log'.format(para['package'])
+            print('I: $ {}'.format(command), file=sys.stderr)
             if subprocess.call(command, shell=True) != 0:
-                print('E: failed to run dpkg-buildcheck.', file=sys.stderr)
+                print('E: failed to run find debian/{}.'.format(bpackage), file=sys.stderr)
                 exit(1)
+        elif len(para['debs']) > 1:
+            command = 'LANG=C; find debian/tmp -type f 2>&1 | sed -e "s/^debian\/tmp\///" | sort >../{0}.install.log'.format(para['package'])
+            print('I: $ {}'.format(command), file=sys.stderr)
+            if subprocess.call(command, shell=True) != 0:
+                print('E: failed to run find debian/tmp.', file=sys.stderr)
+                exit(1)
+        else:
+            print('E: No binary package was generated.', file=sys.stderr)
+            exit(1)
         print('I: upon return to the shell, current directory becomes {}'.format(para['cwd']), file=sys.stderr)
-        print('I: please execute "cd {0}"'.format(os.getcwd()), file=sys.stderr)
-        print('I: before building binary package with dpkg-buildpackage (or debuild, pdebuild, sbuild, ...).', file=sys.stderr)
+        print('I: please execute "cd {0}" before building the binary package'.format(os.getcwd()), file=sys.stderr)
+        print('I: with dpkg-buildpackage (or debuild, pdebuild, sbuild, ...).', file=sys.stderr)
     elif para['invoke']:
         print('I: {}'.format(para['invoke']), file=sys.stderr)
         if subprocess.call(para['invoke'], shell=True) != 0:
@@ -206,8 +241,8 @@ def main():
             print('I: please execute "cd .." and inspect the build results.'.format(os.getcwd()), file=sys.stderr)
     elif os.getcwd() != para['cwd']:
         print('I: upon return to the shell, current directory becomes {}'.format(para['cwd']), file=sys.stderr)
-        print('I: please execute "cd {0}"'.format(os.getcwd()), file=sys.stderr)
-        print('I: before building binary package with dpkg-buildpackage (or debuild, pdebuild, sbuild, ...).', file=sys.stderr)
+        print('I: please execute "cd {0}" before building the binary package'.format(os.getcwd()), file=sys.stderr)
+        print('I: with dpkg-buildpackage (or debuild, pdebuild, sbuild, ...).', file=sys.stderr)
     return
 
 #######################################################################
