@@ -24,6 +24,7 @@ SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 """
 import glob
 import os
+import subprocess
 import sys
 import debmake.cat
 import debmake.control
@@ -63,8 +64,8 @@ def debian(para):
     ###################################################################
     package = para['debs'][0]['package']    # the first binary package name
     substlist = {
-        '@PACKAGE@': package,
-        '@UCPACKAGE@': package.upper(),
+        '@PACKAGE@': para['package'],
+        '@UCPACKAGE@': para['package'].upper(),
         '@YEAR@': para['year'],
         '@FULLNAME@': para['fullname'],
         '@EMAIL@': para['email'],
@@ -83,30 +84,58 @@ def debian(para):
     ###################################################################
     # check which package have the documentation
     ###################################################################
-    binlist = {'script', 'perl', 'python', 'python3', 'bin'}
-    docpackage = ''
-    for deb in para['debs']:
-        if deb['type'] == 'doc':
-            docpackage = deb['package']
-    if docpackage == '':
-        for deb in para['debs']:
-            if deb['type'] in binlist:
-                docpackage = deb['package']
-                break
-    if docpackage == '':
-        docpackage = para['debs'][0]['package']
+    if para['doc'] == []:
+        docpackage = para['debs'][0]['package'] # 1st package
+    else:
+         docpackage = ''
+    #######################################################################
+    # set export string
+    #######################################################################
+    export_dir = para['base_path'] + '/share/debmake/extra0export/'
+    substlist['@EXPORT@'] = ''
+    if 'compiler' in para['export']:
+        substlist['@EXPORT@'] += debmake.read.read(export_dir + 'compiler').rstrip() + '\n\n'
+    if 'java' in para['export']:
+        substlist['@EXPORT@'] += debmake.read.read(export_dir + 'java').rstrip() + '\n\n'
+    if 'vala' in para['export']:
+        substlist['@EXPORT@'] += debmake.read.read(export_dir + 'vala').rstrip() + '\n\n'
+
+    #######################################################################
+    # set override string
+    #######################################################################
+    override_dir = para['base_path'] + '/share/debmake/extra0override/'
+    substlist['@OVERRIDE@'] = ''
+    if len(para['debs']) == 1:
+        build_dir = 'debian/' + para['debs'][0]['package']
+    else:
+        build_dir = 'debian/tmp'
+    if 'autogen' in para['override']:
+        substlist['@OVERRIDE@'] += debmake.read.read(override_dir + 'autogen').rstrip() + '\n\n'
+    if 'autoreconf' in para['override']:
+        substlist['@OVERRIDE@'] += debmake.read.read(override_dir + 'autoreconf').rstrip() + '\n\n'
+    if 'dbg' in para['override']:
+        substlist['@OVERRIDE@'] += debmake.read.read(override_dir + 'dbg').format(para['dh_strip']).rstrip() + '\n\n'
+    if 'java' in para['override']:
+        substlist['@OVERRIDE@'] += debmake.read.read(override_dir + 'java').rstrip() + '\n\n'
+    if 'judge' in para['override']:
+        substlist['@OVERRIDE@'] += debmake.read.read(override_dir + 'judge').rstrip() + '\n\n'
+    if 'multiarch' in para['override']:
+        substlist['@OVERRIDE@'] += debmake.read.read(override_dir + 'multiarch').rstrip() + '\n\n'
+    if 'pythons' in para['override']:
+        substlist['@OVERRIDE@'] += debmake.read.read(override_dir + 'pythons').rstrip() + '\n\n'
     ###################################################################
     # 4 configuration files which must exist (level=0)
     ###################################################################
     debmake.cat.cat('debian/control', debmake.control.control(para))
-    # skip slow debmake.copyright.copyright if debian/copyright exists
-    if not os.path.isfile('debian/copyright'):
-        debmake.cat.cat('debian/copyright', debmake.copyright.copyright(para['package'], para['license']))
+    debmake.cat.cat('debian/copyright', debmake.copyright.copyright(para['package'], para['license'], para['cdata'], para['xml_html_files'], para['binary_files'], para['huge_files']))
     if para['dh_with'] == set(): # no dh_with
-        substlist['@DHWITH@'] = '\tdh $@'
+        substlist['@DHWITH@'] = ''
     else:
-        substlist['@DHWITH@'] = '\tdh $@ --with "{}"'.format(','.join(para['dh_with']))
-    substlist['@OVERRIDE@'] = para['override']
+        substlist['@DHWITH@'] = '--with {}'.format(','.join(para['dh_with']))
+    if para['dh_buildsystem'] == '': # no --buildsystem
+        substlist['@DHBUILDSYSTEM@'] = ''
+    else:
+        substlist['@DHBUILDSYSTEM@'] = '--buildsystem={}'.format(para['dh_buildsystem'])
     confdir = para['base_path'] + '/share/debmake/extra0/'
     debmake.sed.sed(confdir, 'debian/', substlist, package) # changelog, rules
     os.chmod('debian/rules', 0o755)
@@ -129,9 +158,10 @@ def debian(para):
     # * create templates only for the first binary package:
     #   package.menu, package.docs, package.examples, package.manpages, 
     #   package.preinst, package.prerm, package.postinst, package.postrm
-    # * create for all binary packages: package.install
+    # * create for all but dbg binary packages: package.install
     # * create for lib package: package.symbol
     ###################################################################
+    binlist = {'bin', 'perl', 'python', 'python3', 'ruby', 'script'}
     if extra >= 2:
         if len(para['debs']) == 1: # if single binary deb
             confdir = para['base_path'] + '/share/debmake/extra2single/'
@@ -143,12 +173,13 @@ def debian(para):
                 substlist['@BINPACKAGE@'] = deb['package']
                 type = deb['type']
                 if type in binlist:
-                    if deb['package'] == docpackage:
-                        type = 'binall'
-                    else:
-                        type = 'bin'
+                    type = 'bin'
                 confdir = para['base_path'] + '/share/debmake/extra2' + type + '/'
                 debmake.sed.sed(confdir, 'debian/', substlist, deb['package'])
+                if deb['package'] == docpackage:
+                    type = 'doc'
+                    confdir = para['base_path'] + '/share/debmake/extra2' + type + '/'
+                    debmake.sed.sed(confdir, 'debian/', substlist, deb['package'])
     ###################################################################
     # Rarely used optional files (level=3)
     # Provided as the dh_make compatibilities. (files with ".ex" postfix)
@@ -166,6 +197,14 @@ def debian(para):
         debmake.sed.sed(confdir, 'debian/license-examples/', substlist, package)
     else:
         print('I: run "debmake -x{}" to get more template files'.format(extra + 1), file=sys.stderr)
+    ###################################################################
+    # wrap-and-sort
+    ###################################################################
+    command = 'wrap-and-sort'
+    print('I: $ {}'.format(command), file=sys.stderr)
+    if subprocess.call(command, shell=True) != 0:
+        print('E: failed to run wrap-and-sort.', file=sys.stderr)
+        exit(1)
     return
 
 #######################################################################
